import javax.swing.*;
import java.awt.*;

/**
 * A class that represents a (finite) board for Conway's Life.
 * 
 * @author Phil Howard
 */

public class LifePanel extends JPanel 
{

    // The size of one cell one the screen, in pixels. You can make this
    // smaller if you make a big board.
    private final static int CELL_SIZE = 20;
    private final static int BOARD_WIDTH = 25;
    private final static int BOARD_HEIGHT = 25;

    public final static int FRAME_WIDTH = BOARD_WIDTH*CELL_SIZE;
    public final static int FRAME_HEIGHT = BOARD_HEIGHT*CELL_SIZE;

    private Life game;
    
    /**
     * A constructor for a new Life game
     */
    public LifePanel(){
        game = new Life(BOARD_HEIGHT, BOARD_WIDTH);
    }

    /**
     * Updates the board for the next generation
     */
    public void nextGeneration(){
        game.nextGeneration();
    }
   
    /**
     * Fills the board with random cells
     */
    public void fillRandom(){
        game.reset();
    }

    /**
     * Draws the board
     */
    public void paintComponent(Graphics g){
        boolean[][] board = game.getBoard();        
        g.setColor(Color.WHITE);
        g.fillRect(0,0,FRAME_WIDTH,FRAME_HEIGHT);

        for (int x = 0; x < BOARD_WIDTH; x++){
            for (int y = 0; y < BOARD_HEIGHT; y++){
                if(board[x][y]){
                    g.setColor(Color.BLACK);
                    g.fillRect(x*CELL_SIZE, y*CELL_SIZE, CELL_SIZE, CELL_SIZE);
                }
            }
        }
    }    
}
